/*
 * [Build.java]
 *
 * Summary: Track the build number used for all applications.
 *
 * Copyright: (c) 2005-2014 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.7+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2007-09-19 added comment created with IntelliJ IDEA.
 */
package com.mindprod.common17;

import java.awt.Color;

/**
 * Track the build number used for all applications.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2007-09-19 added comment created with IntelliJ IDEA.
 * @see com.mindprod.htmlmacros.support.JDKandJREVersions;
 * @since 2007-09-19
 */
public class Build
    {
    // declarations

    /**
     * incremented for each microrelease even when version numbers are not changed. Global to all apps.
     */
    public static final int BUILD_NUMBER = 9582;

    /**
     * current year, used for copyright, might differ from Misc.thisYear() if flip copyright a few days early or late
     */
    public static final int THIS_COPYRIGHT_YEAR = 2014;

    /**
     * version of JDK we used to build. repeated in JDKandJREVersion
     */
    public static final String JDK_FULL_VERSION = "1.8.0_25";

    /**
     * version of Jet profile , repeated in JDKandJREVersion
     */
    public static final String JET_PROFILE_VERSION = "1.7.0_55";  // NOT most recent JDK 1.7 !!

    /**
     * version of Jet itself , repeated in JDKandJREVersion, Also com.which.FileType.JET_CURRENT_MP
     */
    public static final String JET_VERSION = "jet10.0-pro-x86" /* jet10.0-pro-amd64, 9.0-pro-x86 */;

    /**
     * name of the code signing cert without .cer
     */
    public static final String MINDPRODCERT = "mindprodcert2014dsa";

    /**
     * where the local files for the mindprod website are:
     */
    public static final String MINDPROD_SOURCE = "E:/com/mindprod";

    /**
     * where the local files for the mindprod website are:
     */
    public static final String MINDPROD_WEBROOT = "E:/mindprod";

    /**
     * old version of JDK. repeated in JDKandJREVersion
     */
    public static final String OLD_JDK_FULL_VERSION = "1.7.0_72";

    /**
     * the user agent we pretend do be, Firefox 33.0
     */
    public static final String USER_AGENT =
            "Mozilla/5.0 (Windows NT 6.1; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0";

    /**
     * background colour of most mindprod pages
     */
    public static final Color BACKGROUND_FOR_BLENDING = new Color( 0xf3fff6 );
    // /declarations
    }
